@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher;
 {
-  $WWW::FetchStory::Fetcher::VERSION = '0.1818';
+  $WWW::FetchStory::Fetcher::VERSION = '0.1819';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1818
+version 0.1819
 
 =head1 DESCRIPTION
 
@@ -1566,25 +1566,6 @@ sub tidy_chars {
     zap_cp1252($string);
 
     my %replace_map = (
-        '‚' => ',',     # 82, SINGLE LOW-9 QUOTATION MARK
-        '„' => ',,',    # 84, DOUBLE LOW-9 QUOTATION MARK
-        '…' => '...',   # 85, HORIZONTAL ELLIPSIS
-        'ˆ' => '^',     # 88, MODIFIER LETTER CIRCUMFLEX ACCENT
-        '‘' => '`',     # 91, LEFT SINGLE QUOTATION MARK
-        '’' => "'",     # 92, RIGHT SINGLE QUOTATION MARK
-        '“' => '"',     # 93, LEFT DOUBLE QUOTATION MARK
-        '”' => '"',     # 94, RIGHT DOUBLE QUOTATION MARK
-        '•' => '*',     # 95, BULLET
-        '–' => '-',     # 96, EN DASH
-        '—' => '-',     # 97, EM DASH
-        '‹' => '<',     # 8B, SINGLE LEFT-POINTING ANGLE QUOTATION MARK
-        '›' => '>',     # 9B, SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
-	'e\(tm\)' => "'",
-	'eoe' => '"',
-	'e' => '"',
-	'e~' => "'",
-	'e' => '...',
-	'e"' => '--',
 	'\302' => '',
 	'\240' => ' ',
 	);
